# FETCH_AKS_CREDENTIALS Project

This is an example of how to fetch the AKS credentials from the Azure

# Installing the package

```
pip install fetch_aks_credentials
```

# Usage:

Open you linux terminal and run the following command:

```
get_creds
```

